==> haskell-monad-par-0.3.6-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par
version:              0.3.6
visibility:           public
id:                   monad-par-0.3.6-4EQz3PIkxh48FYUrZRrsvr
key:                  monad-par-0.3.6-4EQz3PIkxh48FYUrZRrsvr
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2011
maintainer:
    Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>

author:               Simon Marlow, Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.

    For complete documentation see "Control.Monad.Par".

    Some examples of use can be found in the @examples/@ directory of
    the source package.

    Other related packages:

    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.

    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.

    Changes in 0.3.4 relative to 0.3:

    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.

    * Added "Control.Monad.Par.IO"

category:             Control,Parallelism,Monads
abi:                  55ea504bb7758a363fb88ab870389349
exposed:              True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal

hidden-modules:       Control.Monad.Par.Scheds.DirectInternal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par
hs-libraries:         HSmonad-par-0.3.6-4EQz3PIkxh48FYUrZRrsvr
depends:
    abstract-deque-0.3-79VVAZyFB2e1QxoctV5GSX
    abstract-par-0.3.3-ISux4E1QYRJK5C39S1lmJd array-0.5.4.0
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    monad-par-extras-0.3.3-FiAOudAFu688erTCLBC49v mtl-2.2.2
    mwc-random-0.15.0.2-Eop8Bz4LJUj4hDWcjuxoAz
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1

haddock-interfaces:   /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html:         /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-0.3.6-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par
version:              0.3.6
visibility:           public
id:                   monad-par-0.3.6-WVbS5B7RG0KYjdihprilN
key:                  monad-par-0.3.6-WVbS5B7RG0KYjdihprilN
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2011
maintainer:
    Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>

author:               Simon Marlow, Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.

    For complete documentation see "Control.Monad.Par".

    Some examples of use can be found in the @examples/@ directory of
    the source package.

    Other related packages:

    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.

    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.

    Changes in 0.3.4 relative to 0.3:

    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.

    * Added "Control.Monad.Par.IO"

category:             Control,Parallelism,Monads
abi:                  ccc382143b359c691c61ab4c12a60caa
exposed:              True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal

hidden-modules:       Control.Monad.Par.Scheds.DirectInternal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par
hs-libraries:         HSmonad-par-0.3.6-WVbS5B7RG0KYjdihprilN
depends:
    abstract-deque-0.3-4BXSPUTvHBaCgd9JqMPS9C
    abstract-par-0.3.3-ISux4E1QYRJK5C39S1lmJd array-0.5.4.0
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    monad-par-extras-0.3.3-KV2GCanxdeW1CJSVrt3E9V mtl-2.2.2
    mwc-random-0.15.1.0-E3ICnwx8GLI7N3W9UJxHMV
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1

haddock-interfaces:   /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html:         /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
